@@ -12,7 +12,7 @@ from inspect import getframeinfo, stack
 from pathlib import Path, PurePath
 from stat import S_IWGRP, S_IWOTH, S_IWUSR, filemode
 from types import TracebackType
-from typing import TYPE_CHECKING, Any, Callable, Iterator, Tuple, Type, Union
+from typing import TYPE_CHECKING, Any
 from uuid import uuid4
 from weakref import WeakValueDictionary
 
@@ -21,6 +21,8 @@ import pytest
 from filelock import BaseFileLock, FileLock, SoftFileLock, Timeout, UnixFileLock, WindowsFileLock
 
 if TYPE_CHECKING:
+    from collections.abc import Callable, Iterator
+
     from pytest_mock import MockerFixture
 
 
@@ -63,7 +65,7 @@ def make_ro(path: Path) -> Iterator[None]:
     path.chmod(path.stat().st_mode | write)
 
 
-@pytest.fixture()
+@pytest.fixture
 def tmp_path_ro(tmp_path: Path) -> Iterator[Path]:
     with make_ro(tmp_path):
         yield tmp_path
@@ -81,7 +83,7 @@ def test_ro_folder(lock_type: type[BaseFileLock], tmp_path_ro: Path) -> None:
         lock.acquire()
 
 
-@pytest.fixture()
+@pytest.fixture
 def tmp_file_ro(tmp_path: Path) -> Iterator[Path]:
     filename = tmp_path / "a"
     filename.write_text("")
@@ -218,7 +220,7 @@ def test_nested_contruct(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
     assert not lock_1.is_locked
 
 
-_ExcInfoType = Union[Tuple[Type[BaseException], BaseException, TracebackType], Tuple[None, None, None]]
+_ExcInfoType = tuple[type[BaseException], BaseException, TracebackType] | tuple[None, None, None]
 
 
 class ExThread(threading.Thread):
@@ -304,7 +306,7 @@ def test_timeout(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
     assert not lock_2.is_locked
 
     # try to acquire lock 2
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."):
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
         lock_2.acquire(timeout=0.1)
     assert not lock_2.is_locked
     assert lock_1.is_locked
@@ -333,44 +335,44 @@ def test_non_blocking(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
     assert not lock_5.is_locked
 
     # try to acquire lock 2
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."):
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
         lock_2.acquire(blocking=False)
     assert not lock_2.is_locked
     assert lock_1.is_locked
 
     # try to acquire pre-parametrized `blocking=False` lock 3 with `acquire`
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."):
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
         lock_3.acquire()
     assert not lock_3.is_locked
     assert lock_1.is_locked
 
     # try to acquire pre-parametrized `blocking=False` lock 3 with context manager
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."), lock_3:
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."), lock_3:
         pass
     assert not lock_3.is_locked
     assert lock_1.is_locked
 
     # try to acquire pre-parametrized `timeout=0` lock 4 with `acquire`
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."):
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
         lock_4.acquire()
     assert not lock_4.is_locked
     assert lock_1.is_locked
 
     # try to acquire pre-parametrized `timeout=0` lock 4 with context manager
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."), lock_4:
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."), lock_4:
         pass
     assert not lock_4.is_locked
     assert lock_1.is_locked
 
     # blocking precedence over timeout
     # try to acquire pre-parametrized `timeout=-1,blocking=False` lock 5 with `acquire`
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."):
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
         lock_5.acquire()
     assert not lock_5.is_locked
     assert lock_1.is_locked
 
     # try to acquire pre-parametrized `timeout=-1,blocking=False` lock 5 with context manager
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."), lock_5:
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."), lock_5:
         pass
     assert not lock_5.is_locked
     assert lock_1.is_locked
@@ -397,7 +399,7 @@ def test_default_timeout(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
     assert not lock_2.is_locked
 
     # try to acquire lock 2
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."):
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
         lock_2.acquire()
     assert not lock_2.is_locked
     assert lock_1.is_locked
@@ -405,7 +407,7 @@ def test_default_timeout(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
     lock_2.timeout = 0
     assert lock_2.timeout == 0
 
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."):
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
         lock_2.acquire()
     assert not lock_2.is_locked
     assert lock_1.is_locked
@@ -459,7 +461,7 @@ def test_del(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
     assert not lock_2.is_locked
 
     # try to acquire lock 2
-    with pytest.raises(Timeout, match="The file lock '.*' could not be acquired."):
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
         lock_2.acquire(timeout=0.1)
 
     # delete lock 1 and try to acquire lock 2 again
@@ -614,8 +616,8 @@ def test_soft_errors(tmp_path: Path, mocker: MockerFixture) -> None:
 def _check_file_read_write(txt_file: Path) -> None:
     for _ in range(3):
         uuid = str(uuid4())
-        txt_file.write_text(uuid)
-        assert txt_file.read_text() == uuid
+        txt_file.write_text(uuid, encoding="utf-8")
+        assert txt_file.read_text(encoding="utf-8") == uuid
 
 
 @pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
@@ -680,7 +682,7 @@ def test_lock_can_be_non_thread_local(
 
 def test_subclass_compatibility(tmp_path: Path) -> None:
     class MyFileLock(FileLock):
-        def __init__(  # noqa: PLR0913 Too many arguments to function call (6 > 5)
+        def __init__(
             self,
             lock_file: str | os.PathLike[str],
             timeout: float = -1,
@@ -689,14 +691,15 @@ def test_subclass_compatibility(tmp_path: Path) -> None:
             my_param: int = 0,
             **kwargs: dict[str, Any],  # noqa: ARG002
         ) -> None:
-            super().__init__(lock_file, timeout, mode, thread_local, blocking=True, is_singleton=True)
+            super().__init__(lock_file, timeout, mode, thread_local, is_singleton=True)
+            self.blocking = True
             self.my_param = my_param
 
     lock_path = tmp_path / "a"
     MyFileLock(str(lock_path), my_param=1)
 
     class MySoftFileLock(SoftFileLock):
-        def __init__(  # noqa: PLR0913 Too many arguments to function call (6 > 5)
+        def __init__(
             self,
             lock_file: str | os.PathLike[str],
             timeout: float = -1,
@@ -812,3 +815,24 @@ def test_file_lock_positional_argument(tmp_path: Path) -> None:
     lock_path = tmp_path / "a"
     lock = FilePathLock(str(lock_path))
     assert lock.lock_file == str(lock_path) + ".lock"
+
+
+@pytest.mark.parametrize(
+    ("lock_type", "expected_exc"),
+    [
+        (SoftFileLock, TimeoutError),
+        (FileLock, TimeoutError) if sys.platform == "win32" else (FileLock, PermissionError),
+    ],
+)
+def test_mtime_zero_exit_branch(
+    lock_type: type[BaseFileLock], expected_exc: type[BaseException], tmp_path: Path
+) -> None:
+    p = tmp_path / "z.lock"
+    p.touch()
+    Path(p).chmod(0o444)
+    os.utime(p, (0, 0))
+
+    lock = lock_type(str(p))
+
+    with pytest.raises(expected_exc):
+        lock.acquire(timeout=0)
